%-------DIPLOMOV PRCE---------
% ====================================
% LOHA PROUDN CHLADIVA V PALIVOVM SOUBORU EEN SUBKANLOVOU ANALZOU
% ====================================
% Autor: Marek Blohoubek
% Verze: 1.0
% Datum: 2020
% ====================================
% <<<<<< INPUTS
% a,d,vh,L,lm - geometrick charakteristiky palivovho souboru
% ro,ni,h,lambda - tabulkov hodnoty vlastnost vody pi konstantnm tlaku
% Mpoc,Tpoc,Qcelk,vykon - okrajov podmnky lohy
% dy,betai,vaha,zastavovaciPodm - parametry vpotu
% q,zetai,tildeh,delta,epsilon - znm konst. hodnoty
% >>>>>> OUTPUTS
% M,W,h,p,rho,u,T - pole vstupnch veliin (pro jednotliv subkanly a ax. souadnice)

clc
%clear all
close all

%-------vstupn geometrick parametry---------
d=9.144e-3; %prmr palivovho proutku [m]
a=12.75e-3; %vzdlenost mezi proutky [m]
vh=57.633e-3; %vka prezu palivovho souboru [m]
L=3630e-3; %dlka palivovho souboru [m]
lm=255e-3; %vzdlenost mezi distannmi a mscmi mkami [m]

%-------------------------------------------------------------------------------
%-------vpoet geometrickch charakteristik palivovho souboru---------
%a)vnitn subkanl
a1=sqrt(3)/2*a; %vka na stranu a (vnitnho subkanlu)
Ai=a*a1/2-0.5*pi*(d/2)^2; %prton plocha vnitnho subkanlu
osi=0.5*pi*d; %smen obvod vnitnho subkanlu
ovi=osi; %vytpn obvod vnitnho subkanlu

%a)vnj subkanl
vhr=vh/(2*sin(pi/3)); %dlka hrany palivovho souboru
a2=(vh-4*a1)/2; %vka vnjho subkanlu
Ao=a*a2+(vhr/2-a)*(a2/2)-7/48*pi*d^2; %prton plocha vnjho subkanlu
oso=7/12*pi*d+vhr/2; %smen obvod vnjho subkanlu
ovo=7/12*pi*d; %vytpn obvod vnjho subkanlu
s1=sqrt((vhr/2-a)^2+a2^2)-d/2; %dlka rozhran vnj-vnj subkanl (pi vrcholu souboru)
s2=a2-d/2; %dlka rozhran vnj-vnj subkanl (na stejn hran)
s3=a-d; %dlka rozhran vnitn-vnitn subkanl

%vpoet vzdlenost sousednch ti (=velikost rozmru kontrolnho objemu l)
xTin=a/2; %souadnice tit vninho subkanlu (v lok. souadnicch)
yTin=a2+sqrt(3)/6*a;

%hodnoty integrl pro vpoet statickch moment subtles vnjho subkanlu (v lok. souadnicch)
Ix=[d^3/24 a2*a^2/2 (d^2*pi*a)/12-(d^3*sqrt(3))/48 (a2/(vhr-2*a))*(vhr^3/24+2*a^3/3-vhr*a^2/2)];
Iy=[-d^3/24+(a2*d^2*pi)/16 a*a2^2/2 (d^2*pi*a2)/12-d^3/16 (a2/(vhr-2*a))^2*(vhr^3/12-2*a^3/3+vhr*a^2-a*vhr^2/2)];

xTout=Ix(2)+Ix(4)-Ix(1)-Ix(3); %souadnice tit vnjho subkanlu (v lok. souadnicch)
yTout=Iy(2)+Iy(4)-Iy(1)-Iy(3);
xTout=xTout/Ao;
yTout=yTout/Ao;

k1=(2*a2)/(vhr-2*a); %koeficienty pmky definujc rozhran vnjch subkanl (v lok. souadnicch)
k2=(vhr*a2)/(vhr-2*a);

l1=sqrt(3)/3*a; %vzdlenost ti pro rozhran vnitn-vnitn subkanl
l2=sqrt((xTin-xTout)^2+(yTin-yTout)^2); %vzdlenost ti pro rozhran vnitn-vnj subkanl
l3=2*xTout; %vzdlenost ti pro rozhran vnj-vnj subkanl na jedn hran
l4=2*(abs(k1*xTout+yTout-k2)/sqrt(k1^2+1)); %vzdlenost ti pro rozhran vnj-vnj subkanl pi vrcholu souboru

%-------------------------------------------------------------------------------
%-------vlastnosti vody pro konst. tlak 15.7MPa v zvislosti na teplot (175-345) s mezikrokem 5C ---------
ro=[901.566 896.482 891.286 ...
    885.976 880.549 875.002 869.330 863.530 857.595 851.521 ...
    845.301 838.929 832.396 825.695 818.816 811.748 804.479 ...
    796.996 789.282 781.321 773.092 ...
    764.569 755.726 746.528 736.934 726.894 716.347 705.216 ...
    693.399 680.766 667.140 652.277 635.803 617.081 594.812]; %hustota [kg/m3]

eta=[15.832 15.372 14.940 ...
    14.531 14.145 13.779 13.431 13.101 12.787 12.487 ...
    12.200 11.925 11.662 11.409 11.164 10.929 10.700 ...
    10.479 10.263 10.053 9.847 ...
    9.645 9.446 9.249 9.053 8.8582 8.662 8.465 ...
    8.265 8.060 7.848 7.626 7.390 7.133 6.839]*1e-5; %dynamick viskozita [Pa*s]

en=[749.151 770.833 792.597 ...
    814.448 836.390 858.431 880.578 902.837 925.22 947.726 ...
    970.375 993.173 1016.131 1039.262 1062.580 1086.099 1109.837 ...
    1133.812 1158.045 1182.560 1207.385 ...
    1232.550 1258.092 1284.054 1310.488 1337.454 1365.030 1393.309 ...
    1422.413 1452.500 1483.785 1516.566 1551.292 1588.715 1630.305]*1000;  %entalpie [J/kg]

lambda=[0.68644 0.68466 0.68268 ...
    0.68049 0.67808 0.67545 0.67260 0.66952 0.66620 0.66264 ...
    0.65882 0.65474 0.65039 0.64575 0.64082 0.63558 0.63002 ...
    0.62412 0.61786 0.61123 0.60421 ...
    0.59680 0.58896 0.58070 0.57200 0.56286 0.55327 0.54324 ...
    0.53275 0.52182 0.51044 0.49859 0.48621 0.47305 0.45864]; %tepeln vodivost [W/m*K]

cp=[4.329 4.344 4.361 ...
    4.379 4.398 4.419 4.440 4.464 4.489 4.515 ...
    4.544 4.575 4.609 4.644 4.683 4.725 4.771 ...
    4.820 4.874 4.933 4.998 ...
    5.069 5.149 5.238 5.338 5.451 5.582 5.734 ...
    5.913 6.129 6.395 6.732 7.182 7.833 8.907]*1000; %mrn tepeln kapacita pi konst. tlaku [J/kg*K]

veliciny=zeros(5,length(ro)); %tabelizovan hodnoty vlastnost vody pi konst. tlaku
veliciny(1,:)=ro;
veliciny(2,:)=eta;
veliciny(3,:)=en;
veliciny(4,:)=lambda;
veliciny(5,:)=cp;

T1=zeros(1,length(ro)); %teplota [C]
for ii=1:length(ro)
    T1(ii)=170+ii*5;
end

%-------proloen veliin polynomem n-tho stupn---------
pocet=length(veliciny(:,1));
T2=175:.5:345;
n=4; %stupe proloen

y2=zeros(pocet,length(T2));

for ii=1:pocet
    p2=polyfit(T1,veliciny(ii,:),n);
    y2(ii,:)=polyval(p2,T2);
    
    %         %-------vykreslen---------
    %         figure
    %         plot(T1,veliciny(ii,:),'o','Linewidth',2)
    %         hold on
    %         plot(T2,y2(ii,:),'Linewidth', 2)
    %         xlabel('Teplota T [^\circC]')
    %         leg=legend('Prokldan hodnoty',['Proloen polynomem ' int2str(n) '. stupn']);
    %
    %         switch ii
    %             case 1
    %                 ylabel('Hustota \rho [kg \cdot m^{-3}]');
    %             case 2
    %                 ylabel('Dynamick viskozita \eta [Pa \cdot s]');
    %             case 3
    %                 ylabel('Mrn entalpie h [kJ \cdot kg^{-1}]');
    %             case 4
    %                 ylabel('Tepeln vodivost \lambda [W \cdot m^{-1} \cdot K^{-1}]')
    %             otherwise
    %                 ylabel('Mrn tepeln kapacita c_{p} [J \cdot kg^{-1} \cdot K^{-1}]')
    %         end
    %         xlim([T2(1) T2(end)]);
    %         upravaGrafu(1,leg);
end

%veliiny v zvislosti na teplot vetn interpolace
ro=[T2;y2(1,:)];
eta=[T2;y2(2,:)];
en=[T2;y2(3,:)];
lambda=[T2;y2(4,:)];
cp=[T2;y2(5,:)];

%-------------------------------------------------------------------------------
%-------Deklarace matice sousednch subkanl a palivovch proutk---------
pocetSubkanalu=36; %celkov poet subkanl
pom=1/6; %pomocn parametry pro vpoet
pom2=1;
pom3=2;
pom4=8;
sousedi=zeros(3,pocetSubkanalu); %matice sousednch palivovch proutk jednotlivch subkanl
%cel st sla udv poadov slo proutku, desetinn st jeho pomrn zastoupen

for ii=1:pocetSubkanalu
    if ii<=6 %1.obvodov ada vnitnch subkanl
        sousedi(1,ii)=1+pom;
        sousedi(2,ii)=ii+1+pom;
        sousedi(3,ii)=ii+2+pom;
        if ii==6
            sousedi(1,ii)=1+pom;
            sousedi(2,ii)=2+pom;
            sousedi(3,ii)=7+pom;
        end
    elseif ii<=24 %2.obvodov ada vnitnch subkanl
        if ii==23
            sousedi(1,ii)=2+pom;
            sousedi(2,ii)=7+pom;
            sousedi(3,ii)=19+pom;
        elseif ii==24
            sousedi(1,ii)=2+pom;
            sousedi(2,ii)=8+pom;
            sousedi(3,ii)=19+pom;
        elseif mod(pom2,3)==2
            sousedi(1,ii)=pom3+pom;
            sousedi(2,ii)=pom3+1+pom;
            sousedi(3,ii)=5+2*pom3+pom;
            
            pom3=pom3+1;
        else
            sousedi(1,ii)=fix((pom4-3)/2)+pom;
            sousedi(2,ii)=pom4+pom;
            sousedi(3,ii)=pom4+1+pom;
            
            pom4=pom4+1;
        end
        pom2=pom2+1;
    else %vnj subkanly (soused pouze se 2 proutky -> posledn dek nulov)
        if ii==36
            sousedi(1,ii)=8+2*pom;
            sousedi(2,ii)=19.25;
        elseif mod(ii,2)==1
            sousedi(1,ii)=ii-17+2*pom;
            sousedi(2,ii)=ii-16+0.25;
        else
            sousedi(1,ii)=ii-17+0.25;
            sousedi(2,ii)=ii-16+2*pom;
        end
    end
end

pom2=1;
pom3=1;
pom4=26;
pom5=9;
souSubkanaly=zeros(3,pocetSubkanalu); %matice sousednch subkanl

for ii=1:pocetSubkanalu %1.obvodov ada vnitnch subkanl
    if ii<=6
        if ii==1
            souSubkanaly(1,ii)=2;
            souSubkanaly(2,ii)=6;
            souSubkanaly(3,ii)=8;
        elseif ii==6
            souSubkanaly(1,ii)=1;
            souSubkanaly(2,ii)=5;
            souSubkanaly(3,ii)=23;
        else
            souSubkanaly(1,ii)=ii-1;
            souSubkanaly(2,ii)=ii+1;
            souSubkanaly(3,ii)=ii*3+5;
        end
    elseif ii<=24 %2.obvodov ada vnitnch subkanl
        if ii==7
            souSubkanaly(1,ii)=8;
            souSubkanaly(2,ii)=24;
            souSubkanaly(3,ii)=25;
        elseif ii==24
            souSubkanaly(1,ii)=7;
            souSubkanaly(2,ii)=23;
            souSubkanaly(3,ii)=36;
        elseif mod(pom2,3)==2
            souSubkanaly(1,ii)=pom3;
            souSubkanaly(2,ii)=ii-1;
            souSubkanaly(3,ii)=ii+1;
            
            pom3=pom3+1;
        else
            souSubkanaly(1,ii)=ii-1;
            souSubkanaly(2,ii)=ii+1;
            souSubkanaly(3,ii)=pom4;
            
            pom4=pom4+1;
        end
        pom2=pom2+1;
    else %vnj subkanly
        if ii==25
            souSubkanaly(1,ii)=7;
            souSubkanaly(2,ii)=26;
            souSubkanaly(3,ii)=36;
        elseif ii==36
            souSubkanaly(1,ii)=24;
            souSubkanaly(2,ii)=25;
            souSubkanaly(3,ii)=35;
        else
            souSubkanaly(1,ii)=pom5;
            if mod(ii,2)==0
                pom5=pom5+1;
            else
                pom5=pom5+2;
            end
            souSubkanaly(2,ii)=ii-1;
            souSubkanaly(3,ii)=ii+1;
        end
    end
end

%-------------------------------------------------------------------------------
%Deklarace stlch geometrick vlastnost prvk
%struktura: | obsah prutocne plochy | delka hrany se sousednim prvkem (1,2,3) | vytpn obvod | smen obvod | vzdlenost ti l se sousednm subkanlem (1,2,3)
vlastnosti=zeros(9,pocetSubkanalu);
pom1=0;

for ii=1:pocetSubkanalu
    if ii<=24
        vlastnosti(1,ii)=Ai;
        vlastnosti(2:4,ii)=s3;
        vlastnosti(5,ii)=ovi;
        vlastnosti(6,ii)=osi;
        
        if ii<=6
            vlastnosti(7:9,ii)=l1;
        else
            vlastnosti(7:8,ii)=l1;
            if mod(pom1,3)==1
                vlastnosti(9,ii)=l1;
            else
                vlastnosti(9,ii)=l2;
            end
            pom1=pom1+1;
        end
        
    else
        vlastnosti(1,ii)=Ao;
        vlastnosti(2,ii)=s3;
        vlastnosti(5,ii)=ovo;
        vlastnosti(6,ii)=oso;
        vlastnosti(7,ii)=l2;
        
        if ii==25
            vlastnosti(3,ii)=s2;
            vlastnosti(4,ii)=s1;
            vlastnosti(8,ii)=l3;
            vlastnosti(9,ii)=l4;
        elseif ii==36
            vlastnosti(3,ii)=s1;
            vlastnosti(4,ii)=s2;
            vlastnosti(8,ii)=l4;
            vlastnosti(9,ii)=l3;
        elseif mod(ii,2)==1
            vlastnosti(3,ii)=s1;
            vlastnosti(4,ii)=s2;
            vlastnosti(8,ii)=l4;
            vlastnosti(9,ii)=l3;
        else
            vlastnosti(3,ii)=s2;
            vlastnosti(4,ii)=s1;
            vlastnosti(8,ii)=l3;
            vlastnosti(9,ii)=l4;
        end
    end
end


%-------------------------------------------------------------------------------
%-------EEN STACIONRN LOHY-----------
%Deklarace okrajovch pormnek
Mpoc=3.7861; %celkov prton hmotnost v ax. smru na vstupu [kg/s] (alternativn 0.7861)
Tpoc=268; %vstupn teplota [C] (alternativn 189)
Qcelk=0.593e6; %celkov vkon svazku [W]
%definovn vektoru vkonu jednotlivch proutk
prevod=Qcelk/19;
vyk=[0.353 0.354 1.717 1.718 1.719];
vykon=[vyk(1) vyk(3) vyk(4) vyk(4) vyk(1) vyk(2) vyk(4) vyk(5) vyk(5) ...
    vyk(5) vyk(4) vyk(2) vyk(1) vyk(1) vyk(2) vyk(2) vyk(1) vyk(2) vyk(5)];
%vykon=[1.122 1.152 0.671 0.691 1.122 1.192 1.192 1.152 0.691 0.701 ...
%    0.691 0.701 0.691 1.172 1.231 1.212 1.212 1.212 1.192];
vykon=vykon*prevod;

%Deklarace vpotovch parametr
dy=5e-3; %prostorov krok v ax. smru [m] (obvykle 5e-3)
y=0:dy:L; %ax. souadnice [m]
beta1=0.11; %konstanta turbulentnho men v mst bez mky [-]
beta2=0.81; %konstanta turbulentnho men v mst s msc mkou [-]
beta3=beta2/4; %konstanta turbulentnho men v mst s distann mkou [-]
vaha=0.2; %vhov koef. pro relaxovn hodnot tlaku, zvisl na max. poadovanm rozdlu tlak a dlce kroku (obvykle 0.2)
zastavovaciPodm=0.05; %zastavovac podmnka iteranho procesu

%Deklarace znmch konstant
A=24*Ai+12*Ao; %celkov prton plocha [m2]
g=9.81; %thov zrychlen [m/s2]
zeta1=0.8; %souinitel mstnho odporu v mst msc mky [-]
zeta2=zeta1/4; %souinitel mstnho odporu na distann mce[-]
tildeh=1000; %souinitel odporu pnho proudn
delta=-0.1; %exponent Re ve vpotu pro vpoet turbulentnho men [-]
epsilon=1; %souinitel penosu hybnosti turbulenc [-]

%-------------------------------------------------------------------------------
%deklarace globlnch matic
M=zeros(pocetSubkanalu,length(y)); %matice prton hmotnosti (v ax. smru) [kg/s]
W=zeros(3*pocetSubkanalu,length(y)); %matice prton hmoty na jednotku dlky (pn proudn zpsoben tlakovmi rozdly) [kg/s m]
h=zeros(pocetSubkanalu,length(y)); %matice mrn entalpie [J /kg]
p=zeros(pocetSubkanalu,length(y)); %matice tlaku [Pa]
u=zeros(pocetSubkanalu,length(y)); %matice rychlosti proudn v ax. smru [m/s]
rho=zeros(pocetSubkanalu,length(y)); %matice hustoty [kg/m3]
T=zeros(pocetSubkanalu,length(y)); %matice teplot [C]

%deklarace matic pro kontrolu funknosti bilannch rovnic
summaM=zeros(1,length(y)); %kontrola rce kontinuity (vsledek mus bt konst.)
summaW=zeros(1,length(y)); %kontrola prton hmoty na jednotku dlky (vsledek mus bt nulov)

%definice umstn distannch a mscch mek
mrizkyMisici=zeros(1,8); %celkov poet velkch mek+1 (u obrzku zprava doleva = zdola nahoru)
mrizkyDistancni=zeros(1,8); %celkov poet malch mek+1 (u obrzku zprava doleva = zdola nahoru)

mrizkyMisici(1)=.340; %poten vzdlenost pro prvn msc mku
mrizkyDistancni(1)=.085;
for ii=2:length(mrizkyMisici)
    mrizkyMisici(ii)=2*lm+mrizkyMisici(ii-1);
    mrizkyDistancni(ii)=2*lm+mrizkyDistancni(ii-1);
end

%-------------------------------------------------------------------------------
%Deklarace okrajov pro vstupn veliiny podmnky
index=vyhledejIndex(T2,Tpoc); %vyhledvn teploty, je je nejble poadovan hodnoty (v danm ppad Tpoc)
for ii=1:pocetSubkanalu
    M(ii,1)=Mpoc*(vlastnosti(1,ii)/A); %vstupn prton hmotnost pro jednotliv subkanly
    h(ii,1)=en(2,index);
    rho(ii,1)=ro(2,index);
    W((ii-1)*3+1,1)=0; %homogenn okrajov podmnka
    W((ii-1)*3+2,1)=0;
    W(3*ii,1)=0;
    p(ii,1)=0; %homog. okr. podm.
    u(ii,1)=M(ii,1)/(rho(ii,1)*vlastnosti(1,ii));
    T(ii,1)=Tpoc;
end

summaM(1)=sum(M(:,1));
summaW(1)=sum(W(:,1));

%-------------------------------------------------------------------------------
%Samotn iteran vpoet
for iy=1:length(y)-1
    %deklarace pomocnch matic pro iterovn hodnot
    Wpom=zeros(1,3*pocetSubkanalu);
    Mpom=zeros(1,pocetSubkanalu);
    ppom=zeros(1,pocetSubkanalu);
    hpom=zeros(1,pocetSubkanalu);
    rhopom=zeros(1,pocetSubkanalu);
    Tpom=zeros(1,pocetSubkanalu);
    upom=zeros(1,pocetSubkanalu);
    
    %-------------------------------------------------------------------------------
    maxRez=20000;
    iterace=1;
    while maxRez>zastavovaciPodm || iterace<=2 %zastavovac podmnka algoritmu pro jednu ax. vrstvu
        if iterace==1
            Wpom(:)=W(:,iy);
            Mpom(:)=M(:,iy);
            ppom(:)=p(:,iy);
            hpom(:)=h(:,iy);
            rhopom(:)=rho(:,iy);
            Tpom(:)=T(:,iy);
            upom(:)=u(:,iy);
        end
        
        %-------------------------------------------------------------------------------
        for ii=1:pocetSubkanalu
            %pomocn promnn pro natn len soustavy
            sumaW=0;
            sumaWu=0;
            sumatildeWu=0;
            sumaTk=0;
            sumatildeWh=0;
            sumaWh=0;
            
            sumaQ=0;
            index1=vyhledejIndex(T2,Tpom(ii));
            
            for ij=1:length(sousedi(:,1))
                ik=souSubkanaly(ij,ii); %index pozice souseda
                il=(ii-1)*3+ij; %pozice v matici W
                Wmin=0.01*((Mpom(ii)+Mpom(ik))/(2*dy));
                
                if abs(Wpom(il))<Wmin
                    uh=0.5*(upom(ii)+upom(ik)); %index h zna hvzdiku
                    duh=2*upom(ii)-0.5*(upom(ii)+upom(ik)); %d zna \Delta
                    rhoh=0.5*(rhopom(ii)+rhopom(ik));
                    if Wpom(il)>0
                        dhh=0;
                    else
                        dhh=hpom(ii)-hpom(ik);
                    end
                else
                    if Wpom(il)>0
                        uh=upom(ii);
                        duh=2*upom(ii)-upom(ii);
                        rhoh=rhopom(ii);
                        dhh=0;
                    else
                        uh=upom(ik);
                        duh=2*upom(ii)-upom(ik);
                        rhoh=rhopom(ik);
                        dhh=hpom(ii)-hpom(ik);
                    end
                end
                
                absW=abs(Wpom(il));
                l=vlastnosti(ij+6,ii);
                H=(tildeh*absW)/(2*rhoh*vlastnosti(ij+1,ii)^2); %odpor pnho proudn [1/s]
                
                %vyhodnocen talkovho pnho proudn
                clen1=Wpom(il)+(dy/uh)*(ppom(ii)-ppom(ik))*(vlastnosti(ij+1,ii)/l);
                clen2=(dy/uh)*(H*Wpom(il)*(vlastnosti(ij+1,ii)/l));
                if abs(clen2)>abs(clen1)
                    Wpom(il)=0; %pn proudn je zcela utlumen
                else
                    if clen1*clen2<=0 %odpor proudn me pouze tlumit (nikoliv bt zdrojem vtho proudn)
                        clen2=-clen2;
                    end
                    Wpom(il)=Wpom(il)+clen1-clen2;  %pepsn hodnot tak, aby se ji mohlo vyhodnocovat z k+1 iterace
                    Wpom(il)=-Wpom(il);
                end
                
                sumaWu=sumaWu+Wpom(il)*duh;
                sumaWh=sumaWh+Wpom(il)*dhh;
                sumaW=sumaW+Wpom(il);
                
                if min(abs(mrizkyMisici-iy*dy))<dy/2 %ax. pozice odpovd pozici msc mky
                    beta=beta2;
                elseif min(abs(mrizkyDistancni-iy*dy))<dy/2 %ax. pozice odpovd pozici distann mky
                    beta=beta3;
                else
                    beta=beta1;
                end
                lambdaIndex=vyhledejIndex(lambda(1,:),Tpom(ii));
                kij=vlastnosti(ij+1,ii)/vlastnosti(ij+6,ii)*lambda(2,lambdaIndex); %souinitel konduknho pestupu tepla mezi sousednmi subkanly [W/m*K]
                sumaTk=sumaTk+kij*(Tpom(ii)-Tpom(ik));
                
                index2=vyhledejIndex(T2,Tpom(ik));
                
                dhcar=4*(vlastnosti(1,ii)+vlastnosti(1,ik))/(vlastnosti(6,ii)+vlastnosti(6,ik)); %car odkazuje na prmrovan hodnoty
                Gcar=(Mpom(ii)+Mpom(ik))/(vlastnosti(1,ii)+vlastnosti(1,ik));
                etacar=0.5*(eta(2,index1)+eta(2,index2)); %aritmetick prmr hodnot dynamick viskozity ii- ik-tho prvku
                Recar=(Gcar*dhcar)/etacar; %aritmetick prmr Reynoldsova sla ii- a ik-tho prvku
                tildeW=beta*Recar^delta*dhcar*Gcar; %plat pro jednofzovou oblast a Beusv model
                %prton hmota na jednotku dlky zpsoben turbulentnmi fluktuacemi [kg / s m]
                
                %korekce turbulentnho proudn v zvislosti na hodnot tlakovho pnho proudn (dle Bowringova modelu)
                if abs(Wpom(il))>4*tildeW
                    tildeWkor=0;
                else
                    tildeWkor=tildeW*(1-(abs(Wpom(il)))/(2*tildeW)+(Wpom(il)/(4*tildeW))^2);
                end
                
                sumatildeWh=sumatildeWh+tildeWkor*(hpom(ii)-hpom(ik));
                sumatildeWu=sumatildeWu+tildeWkor*(upom(ii)-upom(ik));
                
                im=fix(sousedi(ij,ii));
                if im~=0
                    sumaQ=sumaQ+(vykon(im)/L)*mod(sousedi(ij,ii),1);
                end
                
            end
            
            %-------------------------------------------------------------------------------
            %prpravn vpoty ped samotnm vyhodnocenm veliin
            dh=4*vlastnosti(1,ii)/vlastnosti(6,ii);
            G=Mpom(ii)/vlastnosti(1,ii); %hustota hmotnostnho toku [kg / m2 s1]
            Re=G*dh/eta(2,index1); %Reynoldsovo slo [-]
            Pr=(eta(2,index1)*cp(2,index1))/lambda(2,index1); %Prandtlovo slo [-]
            xi=(1.82*log10(Re)-1.64)^(-2); %souinitel techo odporu [-]
            
            Nu=0.023*Re^0.8*Pr^0.4;
            alfa=Nu*lambda(2,index1)/dh; %souinitel pestupu tepla [W / m2 K]
            
            %korekce pro len xi
            ts=0; %teplota na stn palivovho proutku
            Apom=pi*d*L;
            for ij=1:length(sousedi(:,1))
                im=fix(sousedi(ij,ii));
                if im~=0
                    ts=ts+Tpom(ii)+((vykon(im)/Apom)/alfa); %pedpokld, e jsou vechny pspvky od proutk rovnocenn (zanedbvme)
                else
                    ts=ts+Tpom(ii); %pspvek od hranice geometrie je nulov (nepispv k ohevu)
                end
            end
            
            ts=ts/3;
            index3=vyhledejIndex(T2,ts);
            
            xikor=xi*(1+(vlastnosti(5,ii)/vlastnosti(6,ii))*((eta(2,index3)/eta(2,index1))^0.6-1));
            
            if min(abs(mrizkyMisici-iy*dy))<dy/2
                zeta=zeta1; %ax. souadnice odpovd msc mce
            elseif min(abs(mrizkyDistancni-iy*dy))<dy/2
                zeta=zeta2; %ax. souadnice odpovd distann mce
            else
                zeta=0;
            end
            
            %-------------------------------------------------------------------------------
            %iterace veliin ze zkon zachovn
            if iterace==1
                M(ii,iy+1)=Mpom(ii)-dy*sumaW;
                p(ii,iy+1)=ppom(ii)+(dy/vlastnosti(1,ii))*(sumaWu-epsilon*sumatildeWu)-dy*rhopom(ii)*g-...
                    (M(ii,iy+1)/vlastnosti(1,ii))^2*((xikor*dy)/(2*rhopom(ii)*dh)+zeta/(2*rhopom(ii)));
                h(ii,iy+1)=hpom(ii)+dy/M(ii,iy+1)*(sumaQ-sumaTk-sumatildeWh+sumaWh);
                
            else
                M(ii,iy+1)=Mpom(ii)-dy*sumaW;
                p(ii,iy+1)=ppom(ii)+(dy/vlastnosti(1,ii))*(sumaWu-epsilon*sumatildeWu);
                h(ii,iy+1)=hpom(ii)+dy/M(ii,iy+1)*(-sumaTk-sumatildeWh+sumaWh);
                %                                 M(ii,iy+1)=Mpom(ii)-dy*sumaW;
                %                                 p(ii,iy+1)=ppom(ii)+(dy/vlastnosti(1,ii))*sumaWu;
                %                                 h(ii,iy+1)=hpom(ii)+dy/M(ii,iy+1)*sumaWh;
                
                %Gaussova-Seidelova relaxan metoda
                M(ii,iy+1)=vaha*Mpom(ii)+(1-vaha)*M(ii,iy+1);
                p(ii,iy+1)=vaha*ppom(ii)+(1-vaha)*p(ii,iy+1);
                h(ii,iy+1)=vaha*hpom(ii)+(1-vaha)*h(ii,iy+1);
            end
            
            index=vyhledejIndex(en(2,:),h(ii,iy+1));
            
            %iterace veliin z tabulkovch hodnot
            T(ii,iy+1)=en(1,index);
            rho(ii,iy+1)=ro(2,index);
            u(ii,iy+1)=M(ii,iy+1)/(rho(ii,iy+1)*vlastnosti(1,ii));
        end
        
        for ii=1:pocetSubkanalu
            %korektorov vpoet pro rho
            ppuv=p(:,iy+1);
            p(ii,iy+1)=p(ii,iy+1)-(M(ii,iy+1)/vlastnosti(1,ii))^2*((rhopom(ii)-rho(ii,iy+1))/(rhopom(ii)*rho(ii,iy+1)));
            p(ii,iy+1)=vaha*ppuv(ii)+(1-vaha)*p(ii,iy+1); %relaxace veliiny
            
            Wpuv=Wpom; %pomocn promnn potebn pro zachovn hmoty v kontinuu
            for ij=1:length(sousedi(:,1)) %korektorov vpoet pro uh
                ik=souSubkanaly(ij,ii);
                il=(ii-1)*3+ij;
                Wmin=0.01*((M(ii,iy+1)+M(ik,iy+1))/(2*dy));
                
                if abs(Wpuv(il))<Wmin
                    uhplus=0.5*(u(ii,iy+1)+u(ik,iy+1));
                else
                    if Wpuv(il)>0
                        uhplus=u(ii,iy+1);
                    else
                        uhplus=u(ik,iy+1);
                    end
                end
                Wpom(il)=Wpuv(il)-Wpuv(il)*(uhplus-uh)/uh;
                Wpom(il)=vaha*Wpuv(il)+(1-vaha)*Wpom(il);
            end
        end
        
%         %vykreslen tlumen tlaku v jedn ax. vrstv
%         if iterace==1
%             figure;
%             plot(1:36,p(:,iy+1),'LineWidth',2);
%             hold on;
%             pause(.5)
%         else
%             plot(1:36,p(:,iy+1),'LineWidth',2);
%             hold on;
%             pause(.5)
%         end
        
        iterace=iterace+1;
        
        Rezp=max(abs((ppom(:)-p(:,iy+1))./ppom(:)));
        RezM=max(abs((Mpom(:)-M(:,iy+1))./Mpom(:)));
        Rezh=max(abs((hpom(:)-h(:,iy+1))./hpom(:)));
        maxRez=max([Rezp RezM Rezh]);
        disp(maxRez)
        %    maxRez=0;
        
        %pepsn hodnot do globlnch matic
        W(:,iy+1)=W(:,iy+1)+Wpom(:);
        Wpom(:)=zeros(1,pocetSubkanalu*3);
        Mpom(:)=M(:,iy+1);
        hpom(:)=h(:,iy+1);
        ppom(:)=p(:,iy+1);
        upom(:)=u(:,iy+1);
        rhopom(:)=rho(:,iy+1);
        Tpom(:)=T(:,iy+1);
    end
    
%     %dokonen popisk k relaxaci tlak
%     Legend=cell(iterace,1); %generovn legendy s promnnm potem prvk
%     for ii=1:iterace
%         Legend{ii}=strcat(['iterace ', num2str(ii)]);
%     end
%     leg=legend(Legend);
%     xlabel('slo subkanlu')
%     ylabel('Tlak p [Pa]')
%     xlim([1 36])
%     upravaGrafu(1,leg)
    
    %kontrola rce kontinuity
    summaM(iy+1)=sum(M(:,iy+1));
    summaW(iy+1)=sum(W(:,iy+1));
end
